@@ -113,15 +113,12 @@ pub struct Addon {
 // AddonOpts enum
 
 #[cfg_attr(feature = "jsonschemas", derive(JsonSchema))]
-#[derive(Serialize, Deserialize, Eq, PartialEq, PartialOrd, Ord, Clone, Debug)]
-#[serde(untagged)]
-pub enum AddonOpts {
-    PostgreSql {
-        #[serde(rename = "version")]
-        version: String,
-        #[serde(rename = "encryption")]
-        encryption: String,
-    },
+#[derive(Serialize, Deserialize, Eq, PartialEq, PartialOrd, Ord, Clone, Debug, Default)]
+pub struct AddonOpts {
+    #[serde(rename = "version", skip_serializing_if = "Option::is_none")]
+    pub version: Option<String>,
+    #[serde(rename = "encryption", skip_serializing_if = "Option::is_none")]
+    pub encryption: Option<String>,
 }
 
 // -----------------------------------------------------------------------------
